pub fn startup_document_lock_path_for(doc: &Path) -> Option<PathBuf>Expand description
Compute <project_root>/.agent-doc/starting/<hash>.lock for a document.
Returns None when the startup directory cannot be resolved. Falls back to
hashing the input path text when the document hash cannot be derived from the
filesystem.